.. MontePy documentation master file, created by
   sphinx-quickstart on Thu Apr 21 15:29:53 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MontePy's documentation!
===================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   starting

   utilities

   tricks

   faq

   developing

   api/modules

   publications

See Also
========

* `MontePy github Repository <https://github.com/idaholab/montepy>`_ 
* `MCNP 6.2 User Manual <https://mcnp.lanl.gov/pdf_files/TechReport_2017_LANL_LA-UR-17-29981_WernerArmstrongEtAl.pdf>`_
* `MCNP 6.3 User Manual <https://mcnp.lanl.gov/pdf_files/TechReport_2022_LANL_LA-UR-22-30006Rev.1_KuleszaAdamsEtAl.pdf>`_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
